package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`/@`!````J!]```````!``````````$BS````
M`````````$``.``)`$``'``;``8````%````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````*R>````````K)X`````````
M`"````````$````&````H*T```````"@K6```````*"M8```````F`0`````
M``!(%0``````````(````````@````8```"XK0```````+BM8```````N*U@
M``````!``@```````$`"````````"``````````$````!````%0"````````
M5`)```````!4`D```````$0`````````1``````````$`````````%#E=&0$
M````V)<```````#8ET```````-B70```````Y`````````#D``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````*"M````````H*U@``````"@K6``
M`````&`"````````8`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````(`````0`
M```4`````P```$=.50"HGCR*;--,ZF<K.\[N3,-PM)R'KA$```!!````!```
M``@````@'!``!4`$AB@"0`"0A@&(PBD`($D@!`NXHCA%N@0""D$```!"````
M1@```$H```!+````40```%,```!5````60```%L`````````70```&````!A
M````8@``````````````>_!*:V[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#KB-
M\0[59-1\V7%8'.)'Q@&L2^/`NN.2?,+E/RSZH6Q@LP&+;VH)0]:'^9R!9J_,
M9L6YG$!"1=7LQ(D%D(@'<-,Y\HL<#!3BGLG5LG':S>.>,V+;[0PZEPM6I)N6
MI]VC:W^IG)OAIP(*"HH05Z/@^TD```````````````````````````````!"
M`0``$@````````````````````````#@`0``$@``````````````````````
M``";`@``$@````````````````````````!P`@``$@``````````````````
M```````1````(`````````````````````````"B`@``$@``````````````
M```````````G`P``$@````````````````````````"D`0``$@``````````
M``````````````"W`@``$@`````````````````````````/`P``$@``````
M```````````````````'`P``$@`````````````````````````.`0``$@``
M``````````````````````#@`P``$@`````````````````````````]`0``
M$@````````````````````````#3`@``$@````````````````````````#%
M`@``$@````````````````````````"*`@``$@``````````````````````
M```@`P``$@````````````````````````!$`P``$@``````````````````
M``````!]`0``$@````````````````````````">````$@``````````````
M``````````"R`0``$@`````````````````````````R`0``$@``````````
M```````````````-`@``$@````````````````````````"!`@``$@``````
M``````````````````!9`@``$@````````````````````````!X`@``$@``
M``````````````````````!:`0``$@````````````````````````"P`@``
M$@````````````````````````#;`0``$@````````````````````````!Y
M`P``$@````````````````````````!R`P``$@``````````````````````
M``#^````$@`````````````````````````W`P``$@``````````````````
M```````M````(`````````````````````````#G`@``$@``````````````
M``````````#"````$@````````````````````````#Y`0``$@``````````
M``````````````!F`0``$@`````````````````````````=`0``$@``````
M``````````````````!J````$@````````````````````````"6`0``$@``
M``````````````````````!U````$@````````````````````````#N`@``
M$@````````````````````````#S````$@````````````````````````#1
M````$@````````````````````````"H`@``$@``````````````````````
M``#4`0``$@````````````````````````!C`P``$@``````````````````
M``````!+`P``$@````````````````````````"0````$@``````````````
M``````````!K`P``$@````````````````````````"^`@``$@``````````
M```````````````\````(`````````````````````````"!````$@``````
M```````````````````P`P``$@````````````````````````"Y````$@``
M``````````````````````#\`@``$@````````````````````````!K`@``
M$@````````````````````````#Q`0``$@````````````````````````#9
M`@``$@````````````````````````!0````(```````````````````````
M``#,`@``$@````````````````````````!5`P``$@``````````````````
M``````!M`0``$@```&`:0`````````````````#I`P``$@`-`/!50```````
M;P````````"W`P``$@`.``170``````````````````.!```$@`-`+!%0```
M````<`P```````"&`P``$@`-`.`=0```````R`$```````"]`P``$@`-`"`_
M0```````!0````````!\!```$@`-`#`_0```````R@$```````!V!```$@`+
M`+`90`````````````````"I!```$@`-`"!20```````RP,```````"<`P``
M$``9`#BR8`````````````````#U`P``$@`-``!!0```````)``````````H
M!```$0`/`!!70```````!`````````"H`P``$``9`.C"8```````````````
M``!T!```$@`-`.`]0```````*@````````")!```$@`-`(!$0```````)0$`
M``````";!```$@`-`/!#0```````5``````````;!```$``8`!BR8```````
M``````````#B````$@```"`=0``````````````````"!```$@`-`#!!0```
M````V0````````"+`P``$0`9`&BR8```````"`````````"5`P``$``8`#BR
M8`````````````````",`P``(0`9`&BR8```````"`````````!=!```$0`8
M`#"R8```````"``````````9`P``$0`9`("R8```````"`````````"M`P``
M$@`-``!70````````@````````!'`0``$@```'`<0`````````````````!-
M!```$@`-`)!60```````90`````````A!```$@`-`*@?0```````````````
M```=!```(``8`!BR8`````````````````"+`0``$0`9`$"R8```````!```
M``````"-`P``(0`9`&BR8```````"`````````#.`P``$@`-`%!$0```````
M)``````````W!```$@`-`&`^0```````N0````````"L````$0`9`&"R8```
M`````0````````!G!```$@`-`!!"0```````VP$`````````;&EB<&5R;"YS
M;RXU+C(R`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A
M<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`4&5R;%]N97=84P!097)L7VUG7W-E=`!097)L7W-V7W-E='!V;@!0
M97)L7V%V7V9E=&-H`%!E<FQ?<W9?<V5T<'8`4$Q?9&]?=6YD=6UP`'!E<FQ?
M<G5N`%!E<FQ?<WES7VEN:70S`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%]A=&9O
M<FM?;&]C:P!P97)L7W!A<G-E`%!E<FQ?9W9?9F5T8VAP=@!P97)L7V-O;G-T
M<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!P97)L7V%L;&]C`'!E<FQ?9G)E
M90!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S869E<WES;6%L;&]C`&)O;W1?
M1'EN84QO861E<@!P97)L7V1E<W1R=6-T`%!,7W1H<E]K97D`4&5R;%]S>7-?
M=&5R;0!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`&QI8G!T:')E
M860N<V\N,`!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`
M<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!L:6)N<VPN<V\N,0!L:6)D;"YS
M;RXR`&QI8FTN<V\N-@!L:6)C<GEP="YS;RXQ`&QI8G5T:6PN<V\N,0!L:6)C
M+G-O+C8`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P
M`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL
M;V,`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?
M7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`
M;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C
M=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H
M:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E
M;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN
M:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT
M;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET
M7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(N
M-0!'3$E"0U\R+C$T`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N
M-`````(``P`"``(````"``(````"``(``@````(````"``(`!``"``(`````
M```````#``(`!0`"`````@`#``(``@````8````'`````P`"````````````
M!@```````@`#``(``@````(``@```````@````(``@`#``8````"``8````!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`"``$``@`!``(`
M`0````$``0`!`````@`!``$````!``$``0#$`0``$````"````!U&FD)```#
M`+\$`````````0`%`$\"```0`````````)21E@8```<`RP0``!````!T&6D)
M```&`-8$```0````<AEI"0``!0#B!```$````!1I:0T```0`[@0``!````!U
M&FD)```"`+\$````````^*]@```````&````(P``````````````0+)@````
M```%````7@``````````````8+)@```````%````8@``````````````:+)@
M```````%````5```````````````@+)@```````%````6```````````````
M&+!@```````'`````0``````````````(+!@```````'`````@``````````
M````*+!@```````'`````P``````````````,+!@```````'````!```````
M````````.+!@```````'````!@``````````````0+!@```````'````!P``
M````````````2+!@```````'````"```````````````4+!@```````'````
M"0``````````````6+!@```````'````00``````````````8+!@```````'
M````"@``````````````:+!@```````'````"P``````````````<+!@````
M```'````#```````````````>+!@```````'````#0``````````````@+!@
M```````'````#@``````````````B+!@```````'````#P``````````````
MD+!@```````'````$```````````````F+!@```````'````$0``````````
M````H+!@```````'````$@``````````````J+!@```````'````$P``````
M````````L+!@```````'````%```````````````N+!@```````'````%0``
M````````````P+!@```````'````%@``````````````R+!@```````'````
M%P``````````````T+!@```````'````&```````````````V+!@```````'
M````&0``````````````X+!@```````'````&@``````````````Z+!@````
M```'````&P``````````````\+!@```````'````'```````````````^+!@
M```````'````'0```````````````+%@```````'````'@``````````````
M"+%@```````'````'P``````````````$+%@```````'````(```````````
M````&+%@```````'````(0``````````````(+%@```````'````(@``````
M````````*+%@```````'````(P``````````````,+%@```````'````)```
M````````````.+%@```````'````)0``````````````0+%@```````'````
M)@``````````````2+%@```````'````)P``````````````4+%@```````'
M````*```````````````6+%@```````'````*0``````````````8+%@````
M```'````6@``````````````:+%@```````'````*@``````````````<+%@
M```````'````*P``````````````>+%@```````'````+```````````````
M@+%@```````'````+0``````````````B+%@```````'````+@``````````
M````D+%@```````'````+P``````````````F+%@```````'````,```````
M````````H+%@```````'````,0``````````````J+%@```````'````,@``
M````````````L+%@```````'````,P``````````````N+%@```````'````
M4@``````````````P+%@```````'````-```````````````R+%@```````'
M````-0``````````````T+%@```````'````-P``````````````V+%@````
M```'````.```````````````X+%@```````'````.0``````````````Z+%@
M```````'````.@``````````````\+%@```````'````.P``````````````
M^+%@```````'````/````````````````+)@```````'````/0``````````
M````"+)@```````'````/P``````````````$+)@```````'````0```````
M````````2(/L"$B+!3V6(`!(A<!T!>@[`@``2(/$",,```````#_-3*6(`#_
M)326(``/'T``_R4REB``:`````#IX/____\E*I8@`&@!````Z=#_____)2*6
M(`!H`@```.G`_____R4:EB``:`,```#IL/____\E$I8@`&@$````Z:#_____
M)0J6(`!H!0```.F0_____R4"EB``:`8```#I@/____\E^I4@`&@'````Z7#_
M____)?*5(`!H"````.E@_____R7JE2``:`D```#I4/____\EXI4@`&@*````
MZ4#_____)=J5(`!H"P```.DP_____R72E2``:`P```#I(/____\ERI4@`&@-
M````Z1#_____)<*5(`!H#@```.D`_____R6ZE2``:`\```#I\/[___\ELI4@
M`&@0````Z>#^____):J5(`!H$0```.G0_O___R6BE2``:!(```#IP/[___\E
MFI4@`&@3````Z;#^____)9*5(`!H%````.F@_O___R6*E2``:!4```#ID/[_
M__\E@I4@`&@6````Z8#^____)7J5(`!H%P```.EP_O___R5RE2``:!@```#I
M8/[___\E:I4@`&@9````Z5#^____)6*5(`!H&@```.E`_O___R5:E2``:!L`
M``#I,/[___\E4I4@`&@<````Z2#^____)4J5(`!H'0```.D0_O___R5"E2``
M:!X```#I`/[___\E.I4@`&@?````Z?#]____)3*5(`!H(````.G@_?___R4J
ME2``:"$```#IT/W___\E(I4@`&@B````Z<#]____)1J5(`!H(P```.FP_?__
M_R42E2``:"0```#IH/W___\E"I4@`&@E````Z9#]____)0*5(`!H)@```.F`
M_?___R7ZE"``:"<```#I</W___\E\I0@`&@H````Z6#]____)>J4(`!H*0``
M`.E0_?___R7BE"``:"H```#I0/W___\EVI0@`&@K````Z3#]____)=*4(`!H
M+````.D@_?___R7*E"``:"T```#I$/W___\EPI0@`&@N````Z0#]____);J4
M(`!H+P```.GP_/___R6RE"``:#````#IX/S___\EJI0@`&@Q````Z=#\____
M):*4(`!H,@```.G`_/___R6:E"``:#,```#IL/S___\EDI0@`&@T````Z:#\
M____)8J4(`!H-0```.F0_/___R6"E"``:#8```#I@/S___\E>I0@`&@W````
MZ7#\____)7*4(`!H.````.E@_/___R5JE"``:#D```#I4/S___\E8I0@`&@Z
M````Z4#\____)5J4(`!H.P```.DP_/___R52E"``:#P```#I(/S___\E2I0@
M`&@]````Z1#\____)4*4(`!H/@```.D`_/___R4ZE"``:#\```#I\/O__U-(
M@^PPB7PD'$B)="002(U\)!Q(B50D"$B-="002(U4)`CH&?[__[IP'$``OR`=
M0`!(B=;H1S@``(`]0)0@``!U+^@9_?__2(7`2(D%KZ0@``^$9P$``$B)Q^A1
M_/__BSW[DR``Z.;]___&@,4(````BSWIDR``Z-3]__^`B,($```"BSW7DR``
MZ,+]__^`B,($```!BT0D'(UX!4AC_TC!YP/H"/W__TR+3"002(D%-*0@`,<%
M,J0@``0```!)BQ%(QT`([UA``$C'0!CR6$``2(D02(L5=9,@`$B)4!"+5"0<
M@_H!?BF-2OXQ]DB#P0$/'X``````38M$\0B-?@5(@\8!2#G.2&/_3(E$^/AU
MYXU*!$B+/>6C(`"#P@-%,<"^$#Y``$ACR4C'1,CX`````$B)P>B6_?__A<")
MPW0[2(L]N:,@`.CD^___2(UT)"PQP+^S5T``Z,,8``!(A<!T*4B+/9>C(`#H
M8OO__^@M_?__2(/$,(G86\-(BSU^HR``Z`G^__^)P^NU2(L]9J,@`$B%_W0'
MZ'0V``#KQ$B-="0LOVA70`#H<Q@``$B%P$B)QTB)!3ZC(`!TINO9OP$```#H
MZ/W__S'M28G17DB)XDB#Y/!05$G'P`!70`!(Q\&05D``2,?'X!U``.CO^___
M]&8N#Q^$```````/'T``N#^R8`!52"TXLF``2(/X#DB)Y78;N`````!(A<!T
M$5V_.+)@`/_@9@\?A```````7<-F9F9F9BX/'X0``````+XXLF``54B![CBR
M8`!(P?X#2(GE2(GP2,'H/T@!QDC1_G05N`````!(A<!T"UV_.+)@`/_@#Q\`
M7<-F#Q]$``"`/2&2(```=1%52(GEZ&[___]=Q@4.DB```?/##Q]``+^PK6``
M2(,_`'4%ZY,/'P"X`````$B%P'3Q54B)Y?_07>EZ____9BX/'X0``````$%7
M059,C4<X055!5#'V55-(@>P0`@``9@\?A```````28L$,$B)PDB)P4C!X@A(
MP>$8@>(``/\`B<E("<I(B<%(P>D(@>$`_P``2`G*2(G!2,'I&`^VR4@)RDB)
M5'2(2(G"2,'J($F)T4B)T4G!X0A(P>$808'A``#_`(G)3(G*2`G*2(G!2,'H
M.$C!Z2B!X0#_``!("<I("=!(B41TD$B#Q@A(@_Y`#X5S____2(U$)(A(C5!H
M2(VP:`(```\?`$B+0MA(,P)(@\((2#-"H$@S0I!(B<%(`<!(P>D?2`G(@^#_
M2(E"$$@Y\G743(L/2(MO($R+5PA,BU\02(M?&$B)ZDR)R4@#5"2(3(G(2,'I
M&TV)U4C!X`5)P>T"2(G>2`G(2`-T))!-B<R)P$G![`)(C8P"F7F"6DR)T$R)
MVDCWT$PATD@AV$@)T$R)TDC!XAY(`<A,B<E)"=5(]]%!B<=%B>U,(=E-B>A(
MB<I-(<A,"<)(C8P6F7F"6DR)_DR)^DC![AM(P>(%2`GRB=)(C3013(G*3(GY
M2,'B'DCWT4D)U$R)VD@#5"2818GD3"'I08GP3"'@3`-L)*!("<%,B<!(C90*
MF7F"6DR)P4C!X`5(P>D;2`G(B<!(C0P"3(GZ3(GX2,'@'DC!Z@)("<),B<!!
MB<Z)TDCWT$PAX$@AUDP#9"2H2`G&3(GP28VT-9EY@EI-B?5(P>`%2<'M&TP)
MZ(G`3(TL!DR)P$G!X!Y(P>@"20G`3(GP18GO18G`2/?02"'03"'!2`-4)+!(
M"<%,B?A)C;0,F7F"6DR)^4C!X`5(P>D;2`G(B<!(C0P&3(GP2<'F'DC!Z`),
MB?Y)"<9(]]9!B<Q$B?!,(<9,`T0DN$DAQ4D)]4R)YDZ-K"J9>8):3(GB2,'F
M!4C!ZAM("?),B?Y)P><>2,'N`HG23`'J20GW38GE1(G^2??508G622'%2"'Q
M3`GI38VL")EY@EI-B?!,B?%)P>@;2,'A!4@#1"3`3`G!B<E-C40-`$R)X4G!
MY!Y(P>D"20G,18G%1(GA38GT2??42"'*22'T2`-T),A,">),C:00F7F"6DR)
MZ$R)ZDC!X@5(P>@;2`G03(GR2<'F'DC!Z@*)P$D)UDP!X$2)\DV)[D&)Q$GW
MUDDAT$DASD@#3"3030GP3HVT!IEY@EI,B>9-B>!)P>`%2,'N&TP)QDV)Z$G!
MY1Y)P>@"B?9-"<5,`?9%B>A-B>5!B?9)]]5,(<!)(=5,">A,C:P!F7F"6DR)
M\4R)\$C!Z1M(P>`%2`-4)-A("<B)P$F-3`4`3(G@2<'D'DC!Z`))"<1!B<U$
MB>!-B?1)]]1((<9-(<1,`T0DX$P)YDR-I#*9>8):3(GJ3(GN2,'F!4C!ZAM(
M"?),B?9)P>8>2,'N`HG220GV3`'B1(GV38GN08G42??62"'Q22'&2`-$).A,
M"?%-C;0(F7F"6DV)X$R)X4G!Z!M(P>$%3`G!B<E-C00.3(GI2<'E'DC!Z0))
M"<U%B<9$B>E-B>5)]]5((<I)(?5,">I,C:P0F7F"6DR)\$R)\DC!X@5(P>@;
M2`G03(GBB<!,`>A(P>H"2<'D'DD)U$@#="3P08G%1(GB38GT2??422'022',
M2`-,)/A-">!.C:0&F7F"6DR)[DV)Z$G!X`5(P>X;3`G&38GP2<'F'DG!Z`*)
M]DT)QDP!YD6)\$V)[D&)]$GWUDPAP$DAUD@#%"1,"?!,C;0!F7F"6DR)X4R)
MX$C!Z1M(P>`%2`G(B<!)C0P&3(GH2<'E'DC!Z`))"<5!B<]$B>A-B>5)]]5(
M(<9-(<5,">Y,C:PRF7F"6DR)^DR)_DC!Y@5(P>H;2`GR3(GFB=),`>I(P>X"
M2<'D'DD)]$P#1"0(08G61(GF38G\38GU2??42"'Q2<'M&TDAQ$@#1"003`GA
M38V$")EY@EI,B?%(P>$%3`GIB<E-C2P(3(GY2<'G'DC!Z0)-B?!)"<])]]!%
MB>Q$B?E)(?!(`W0D&$@ARDP)PDV)X$B-E!"9>8):3(G@2<'H&TC!X`5,"<")
MP$R-!`),B?))P>8>2,'J`DD)UD2)P$2)\DV)YDF)QTGWUDDAU4G![QM)(<Y-
M"?5.C:PNF7F"6DB)QDC!Y@5,"?Z)]DV-?#4`38GE2<'D'DG![0)(B<9-">5(
M`TPD($CWUD6)[$@AUD6)_DTAX$@#5"0H3`-D)#!)"?!,B?9.C80!F7F"6DR)
M\4C![AM(P>$%2`GQB<E)C30(2(G!2,'@'DC!Z0)("<A!B?!),<5%,>]-B<5*
MC8PZH>O9;DR)PDG![1M(P>(%3`GJB=),C2P13(GQ2<'F'DC!Z0),"?%%B>](
MB<I(,<*)P$@#1"0X,=9,B?I-C:0TH>O9;DR)_DC!X@5(P>X;2`GRB=))C304
M38G$2<'@'DG![`)-"<2)\DV)X$DQR(G)13'%28G03HVL**'KV6Y(B=!)P>`%
M2,'H&TP)P$V)^$G!YQY)P>@"2`-,)$")P$T)^$P!Z$V)Q4&)QDTQY40Q[DR-
MK#&AZ]EN3(GQ3(GV2,'F!4C!Z1M("?%(B=9(P>(>2,'N`HG)2`G61(GB2`-4
M)$A)B?1,`>E-,<1!B<]%B<!$,>!,`T0D4$R-I`*AZ]EN3(GX3(GZ2,'B!4C!
MZ!M("=!,B?))P>8>2,'J`HG`3`GR3`'@28G408G%23'TB?9$,>%-C:0(H>O9
M;DV)Z$R)Z4G!Z!M(P>$%3`G!B<E-C00,3(GY2<'G'DC!Z0),"?E(`W0D6$6)
MQDF)S$DQU(G22`-4)&!$,>!,C:0&H>O9;DR)]DR)\$C![AM(P>`%2`GPB<!)
MC30$3(GH2<'E'DC!Z`),">A!B?1)B<5),<V)R4@#3"1H13'H3HVL`J'KV6Y,
MB>)-B>!)P>`%2,'J&TP)PDV)\$G!YAY)P>@"B=)-"?!,`>I-B<9!B=5),<:)
MP$@#1"1P1#'V3(VT,:'KV6Y,B>E,B>Y(P>8%2,'I&T@)\4R)YDG!Y!Y(P>X"
MB<E,">9,`?%)B?1!B<Y-,<1%B<!$,>),C:00H>O9;DR)\$R)\DC!Z!M(P>(%
M3`-$)'A("=!,B>I)P>4>2,'J`HG`3`GJ3`'@28G508G$23'UB?9(`[0D@```
M`$0QZ4V-K`BAZ]EN38G@3(GA2<'H&TC!X05,"<&)R4V-1`T`3(GQ2<'F'DC!
MZ0),"?%%B<5)B<Y),=:)TD@#E"2(````1#'P3(VT!J'KV6Y,B>Y,B>A(P>X;
M2,'@!4@)\(G`28TT!DR)X$G!Y!Y(P>@"3`G@08GV28G$23',B<E%,>!.C:0"
MH>O9;DR)\DV)\$G!X`5(P>H;3`G"38GHB=))P>@"3`'B2<'E'D@#C"20````
M30GH08G438G%23'%B<!(`X0DF````$0Q[DR-K#&AZ]EN3(GA3(GF2,'F!4C!
MZ1M("?%,B?9)P>8>2,'N`HG)3`GV3`'I28GV08G-33'&18G`3`.$)*````!$
M,?),C;00H>O9;DR)Z$R)ZDC!X@5(P>@;2`G03(GB2<'D'DC!Z@*)P$P)XDP!
M\$F)U$&)QDDQ](GV2`.T)*@```!$,>%-B?1-C80(H>O9;DR)\4G![!M(P>$%
M3`GAB<E-C20(3(GI2<'E'DC!Z0),">E%B>!)B<U),=6)TD0QZ$@#E"2P````
M3(VL!J'KV6Y,B<9,B<!(P>X;2,'@!4@)\(G`28UT!0!,B?!)P>8>2,'H`DP)
M\$&)]4F)QDDQSHG)2`.,)+@```!%,?1.C;0BH>O9;DR)ZDV)[$G!Y`5(P>H;
M3`GB38G$2<'@'DG![`*)TDT)Q$P!\DV)X$&)UTDQP(G`2`.$),````!$,<9,
MC80QH>O9;DR)_DR)^4C![AM(P>$%2`GQB<E)C30(38GH2<'E'DG!Z`)-">A!
MB?9,B<%-B?5,,>%)P>T;18GD,<I(C900H>O9;DR)\$C!X`5,">B)P$R-+`),
MB?JXW+P;CTC!Z@))P><>3`GZ28G'3`.\),@```!$B>E-`?Q)B==-"<=,(?Y)
MB==-(<=%B<!$"?Y)B<])`?1(B<Y)P>\;2,'F!4P)_HGV38T\-$R)]DG!YAY(
MP>X"3`GV28G&3`.T)-````!%B?Q-`?!)B?9)"=9-(?5)B?9)(=:)TD4)]4V)
MYDT!Z$V)Y4G![AM)P>4%30GU18GM30'%28G(2,'A'DG!Z`)%B>Y,"<%)B<!,
M`X0DV````$P!PDF)R$D)\$TAQTF)R$DA\(GV10G'38GP3`'Z38GW2<'@!4G!
M[QM-"?A%B<!)`=!,B>))P>0>2,'J`D6)QTD)U$B)PD@#E"3@````2`'R3(GF
M2`G.22'U3(GF2"'.B<E!"?5,B?Y,`>I-B?U(P>8%2<'M&TP)[HGV3(TL,DR)
M\DG!YAY(P>H"3`GR28G&3`.T).@```!$B>Y,`?%)B=9-">9-(?!)B=9-(>9%
MB>1%"?!)B?9,`<%)B?!)P>X;2<'@!4T)\$6)P$Z--`%-B?A)P>@"2<'G'DT)
M^$F)QTP#O"3P````1(GQ30'\38G'20G732']38G'22'7B=)%"?U)B<]-`>Q)
MB<U)P>\;2<'E!4T)_46)[4T!Y4F)]$C!YAY)P>P"18GO3`GF28G$3`.D)/@`
M``!,`>))B?1-"<1-(>9)B?1-(<1%B<!%">9-B?Q,`?)-B?Y)P>0%2<'N&TT)
M]$6)Y$D!U$B)RDC!X1Y(P>H"18GF2`G12(G"2`.4)``!``!,`<))B<A)"?!-
M(<5)B<A)(?")]D4)Q4V)\$P!ZDV)]4G!X`5)P>T;30GH18G`20'03(GZ2<'G
M'DC!Z@)%B<5,"?I)B<=,`[PD"`$``$P!_DF)UTD)STTA_$F)UTDASXG)10G\
M3HT\)DV)[$R)[DC!Y@5)P>P;20GT18GD2XTT)TV)]$G!YAY)P>P"30GT28G&
M3`.T)!`!``!!B?=,`?%-B>9)"=9-(?!-B>9)(=:)TD4)\$Z--`%-B?A,B?E(
MP>$%2<'H&TD)R$6)P$N-#`9-B>A)P>@"2<'E'DT)Z$F)Q4P#K"08`0``08G.
M3`'J38G%30GE3"'N38G%32'E18GD1`GN38GU2`'R3(GV2<'M&TC!Y@5,">Z)
M]DR-+#),B?Y)P><>2,'N`DP)_DF)QTP#O"0@`0``1(GJ30'\28GW30G'3"'Y
M28GW32''18G`1`GY28G720',2(G12<'O&TC!X05,"?F)R4V-/`Q,B?%)P>8>
M2,'I`DP)\4F)QDP#M"0H`0``18G\30'P28G.20GV32'U28G.22'VB?9%"?5-
MB>9-`>A-B>5)P>X;2<'E!4T)]46)[4T!Q4F)T$C!XAY)P>@"18GN3`G"28G`
M3`.$)#`!``!,`<9)B=!)"<A-(<=)B=!)(<B)R44)QTV)\$P!_DV)]TG!X`5)
MP>\;30GX18G`20'P3(GF2<'D'DC![@)%B<=)"?1(B<9(`[0D.`$``$@!\4R)
MYD@)UDDA]4R)YD@AUHG200GU3(G^3`'I38G]2,'F!4G![1M,">Z)]DR-+#%,
MB?9)P>8>2,'N`DP)]DF)QDP#M"1``0``1(GI3`'R28GV30GF32'P28GV32'F
M18GD10GP28G.3`'"28G(2<'N&TG!X`5-"?!%B<!.C30"38GX2<'G'DG!Z`)-
M"?A)B<=,`[PD2`$``$2)\DT!_$V)QTD)]TTA_4V)QTDA]XGV10G]28G730'L
M28G52<'O&TG!Y05-"?U%B>U-`>5)B<Q(P>$>2<'L`D6)[TP)X4F)Q$P#I"10
M`0``3`'F28G,30G$32'F28G,32'$18G`10GF38G\3`'V38G^2<'D!4G![AM-
M"?1%B>1.C30F2(G62,'B'DC![@)("?)(B<9(`[0D6`$``$6)]$@#A"1@`0``
M3`'&28G020G(32'%28G022'(B<E%"<5-B>!(`<A,`>Y-B>5)P>`%2<'M&TT)
MZ$6)P$Z-+`9,B?Y)P><>2,'N`DP)_D6)Z$B)\4@)T4DASDB)\4@AT8G200G.
M3(G!3`'P38G&2,'A!4G![AM,"?&)R4R--`A,B>!)P>0>2,'H`DD)Q+C6P6+*
M1(GQ28G'3`.\)&@!``!,`?I-B>=),?>)]D4Q_4F)STP!ZDF)S4G![QM)P>4%
M30G]38G'2<'@'DG![P)%B>U-"?A)B<=,`[PD<`$``$D!U42)ZDP!_DV)QTTQ
MYT6)Y$4Q_DF)UTP!]DF)UDG![QM)P>8%30G^28G/2,'A'DG![P)%B?9)"<](
MB<%(`XPD>`$``$D!]D2)]DP!X4V)_$TQQ$6)P$4QY4F)]$P!Z4F)]4G![1M)
MP>0%30GE28G42,'B'DG![`)%B>U)"=1(B<)(`Y0D@`$``$D!S42)Z4P!PDV)
MX$TQ^$6)_T4QQDF)R$P!\DF)SDG!X`5)P>X;30G&18GV20'62(GR2,'F'DC!
MZ@)%B?!("=9(B<)(`Y0DB`$``$P!^DF)]TTQYT6)Y$4Q_4V)QTP!ZDV)Q4G!
M[QM)P>4%30GO28G-2,'A'DG![0)%B?])"<U(B<%(`XPDD`$``$D!UT2)^DP!
MX4V)[$DQ](GV13'F28G43`'Q28G62<'D!4G![AM-">9%B?9)`<Y,B<%)P>`>
M2,'I`D6)]$D)R$B)P4@#C"28`0``2`'Q3(G&3#'N18GM03'W3(GF3`'Y38GG
M2,'F!4G![QM)"?=(B=9(P>(>2,'N`D6)_T@)UDB)PD@#E"2@`0``20'/1(GY
M3`'J28GU33'%18G`13'N28G-3`'R28G.2<'E!4G![AM-">Y%B?9)`=9,B>))
MP>0>2,'J`D6)]4D)U$B)PD@#E"2H`0``3`'"38G@23'PB?9%,<=-B>A,`?I-
MB>])P>`%2<'O&TT)QTF)R$C!X1Y)P>@"18G_20G(2(G!2`.,)+`!``!)`==$
MB?I(`?%,B<9,,>9%B>1!,?9(B=9,`?%)B=9(P>8%2<'N&TD)]D6)]DD!SDR)
MZ4G!Y1Y(P>D"1(GV20G-2(G!2`.,)+@!``!,`>%-B>Q-,<1%B<!%,>=)B?1,
M`?E)B?=)P>0%2<'O&TT)YTF)U$6)_TD!STC!XAY)P>P"20G42(G"2`.4),`!
M``!$B?E,`<)-B>!-,>A%B>U%,<9)B<A,`?))B<Y)P>`%2<'N&TT)QD6)]DD!
MUDB)\DC!YAY(P>H"18GP2`G62(G"2`.4),@!``!,`>I)B?5-,>5%B>1%,>]-
MB<5,`?I-B<=)P>4%2<'O&TT)[TF)S4C!X1Y)P>T"18G_20G-2(G!2`.,)-`!
M``!)`==$B?I,`>%-B>Q),?2)]D4QYDF)U$P!\4F)UDG![AM)P>0%30GF18GV
M20'.3(G!2<'@'DC!Z0)%B?1)"<A(B<%(`XPDV`$``$@!\4R)QDPQ[D6)[4$Q
M]TR)YDP!^4V)YTC!Y@5)P>\;20GW2(G62,'B'DC![@)%B?]("=9(B<)(`Y0D
MX`$``$D!ST2)^4P!ZDF)]4TQQ46)P$4Q[DF)S4P!\DF)SDG!Y05)P>X;30GU
M18GM20'53(GB2<'D'DC!Z@)%B>Y)"=1(B<)(`Y0DZ`$``$P!PDV)X$DQ\(GV
M13''38GP3`'Z38GW2<'@!4G![QM-"?A)B<](P>$>2<'O`D6)P$P)^4F)QTP#
MO"3P`0``3`'"08G03`'^28G/33'G18GD13']38G'3`'N38G%2<'O&TG!Y05-
M"?U-B?=)P>8>2<'O`D6)[4T)_DF)QTP#O"3X`0``3`'N08GU30'\38GW23'/
MB<E$,?I-B>])`=1,B>I)P>\;2,'B!4P)^D0!XDV)Q$G!X!Y)P>P"30G@2`.$
M)``"``!-B>Q)P>P"2<'E'D0!]4T)Y4B);R!%`>M,C20(3(G!2(G03#'Q2,'@
M!4$!V#'.3(E?$$R)1QA)C0PT2(G61`'22,'N&TB)5PA("?`!R$$!P4R)#TB!
MQ!`"``!;74%<05U!7D%?PV8N#Q^$``````!!5T%628G^055!5%532(/L"$B%
M_W1H3(L]2WH@`$V%_W1<#[8'28GU/#UT9(3`=&!)B?Q)@\0!00^V!"0\/70$
MA,!U[T4I]$F+'TB%VW0O36/D3(G]#Q\`3(GB3(GV2(G?Z*KA__^%P'4'0H`\
M(SUT)TB#Q0A(BUT`2(7;==I(@\0(,<!;74%<05U!7D%?PY!%,>3KL@\?`$PI
M_4J-1",!2,']`T&);0!(@\0(6UU!7$%=05Y!7\-F#Q^$``````!32(G[2(/L
M$`\?A```````2(UT)`PQP$B)W^@A____2(7`="Y(8U0D#$B+!7AY(`!(C030
M2(M0"$B%TDB)$'302(/`"$B+4`A(A=)(B1!U\.N^2(/$$%O##Q^$``````!!
M5T%6,<!!54%455-(B?-(B?U(@^PH@#X]#Y3`2`'#2(G?Z(GA__](C70D'$F)
MQ$B)[S'`Z*?^__](A<!)B<4/A/L```!(B<?H8^'__TDYQ`^&R@```$QC="0<
M2<'F`P^V10`\/0^$F`$``(3`#X20`0``2(GIZPP/'X0``````(3`=`M(@\$!
M#[8!/#UU\4@IZ4ACR4P#-:QX(`!*C7PA`NAZXO__2(7`28D&#X1E`0``2&-4
M)!Q(BP6*>"``2(U-`4B+%-`/MD4`A,"(`G4:ZQQF#Q]$``!(@\$!#[9!_TB#
MP@&$P(@"=`0\/77JQ@(],<`/'T0```^V#`.(3`(!2(/``83)=?`QP$B#Q"A;
M74%<05U!7D%?PP\?@`````!(@\,!#[9#_TF#Q0&$P$&(1?]U[.O29BX/'X0`
M`````$R+/0%X(`!)@S\`#X2Y````3(GX13'M9@\?A```````2(/`"$&#Q0%(
M@S@`=?)!C44"2)A(C3S%`````(L%'H@@`(7`=#I(B?Y,B?_H'^+__TB%P$B)
M!:UW(`!T>DUCQ4B)P4Z--,4`````2L=$P0@`````1(EL)!SIH?[__V:0QP76
MAR```0```.A1X?__2(7`=$--8\5,B?Y(B<=.C33%`````$R)1"0(3(GRZ-[A
M__],BT0D"$B)P4B)!4=W(`#KJ#')Z8O^__^_$````$4Q[>EE____N/_____I
MZ?[__V9F9F9F9BX/'X0``````$B%_W0%@#\`=0;##Q]$``!!54%455-(B?U(
M@>R8````Z`O?__](A<!)B<0/A+\```!,B>?H=^'__TB%P$B)PP^$FP```(![
M$RX/A+$```!(@\,32(GOZ"7?__](B=])B<7H&M___T&-?`4"2&/_Z'W@__])
MB=E)B<5(B<=)B>BY%%=``$C'PO____^^`0```#'`Z.GA__^_`0```$B)XDR)
M[NAYWO__@_C_3(GO=!"+1"08)0#P```]`$```'1IZ.S=__],B>_HQ-W__TR)
MY^C<X/__2(7`2(G##X5E____3(GGZ"C?__](B>_H@-[__TB!Q)@```!;74%<
M05W#9I`/MD,4A,`/A"7___\\+@^%.____X![%0`/A!/____I+/___P\?1```
MZ-/^___KE9!32(G[BSVV=2``Z*'?__](C9#X`0``2(G>OP$```#HW>#__X7`
M=`DQP%O##Q]$``"+/8IU(`#H==___XN`$`(``"4`\```/0!```!T'8L];74@
M`.A8W___BX`0`@``)0#P```]`*```'6]2(G?O@(```#H.>#__X7`#Y3`#[;`
M6\-F9F9F9F8N#Q^$``````!!5%5)B?132(G]NO\/``"_&E=``$B![!`0``!(
MB>9D2(L$)2@```!(B80D"!```#'`Z.K<__^%P'YNC4C_2&/9@#P<`'1:2&/8
M2(G:OB\```!(B>?H-][__TB%P'1*BSW,="``Z+?>__](B=E(B>)(B>Y(B<?H
MQM___TB+A"0($```9$@S!"4H````=39(@<00$```6UU!7,,/'X``````A<EU
MI0\?0`"+/8)T(`#H;=[__TR)XDB)[DB)Q^A/W?__Z[?H"-W__P\?A```````
M2(/L"(L]5G0@`.A!WO__N1I90`"Z8!I``+XI5T``2(G'2(/$".E6WO__9@\?
M1```2(/L"(L])G0@`.@1WO__2(G'Z+G___^+/1-T(`#H_MW__T&XZ5A``$4Q
MR;H@4D``3(G!OD570`!(B<=(@\0(Z6S>__]F9F8N#Q^$``````!32('L("``
M`&1(BP0E*````$B)A"08(```,<#HT-O__T&Y)5=``$&)P+E:5T``,<"Z`1``
M`+X!````2(GGZ"[?__^%P'AJ2(VT)!`0``"Z`!```$B)Y^AUV___A<!(B<-X
M3HUX`4AC_^ASW?__2(7`=#Y(8]M(C;0D$!```$B)QTB)VN@HW?__Q@08`$B+
ME"08(```9$@S%"4H````=15(@<0@(```6\,/'X0``````#'`Z]CHQ]O__P\?
M@`````#I.____V9F+@\?A```````059!54%454F)]%-(B?N_:%=``$B!["`0
M``!D2(L$)2@```!(B80D&!```#'`2(UT)`SHF?C__[XO````2(G?2(G%Z(G;
M__](A<!T.4B)WK]Q5T``,<#HE?G__TB)V$B+C"08$```9$@S#"4H````#X50
M`0``2('$(!```%M=05Q!74%>PTB)W^@3V___OGY70`!,B>=!B<7H<]W__TB%
MP$F)QG2G0;QF5T``08/%`9!!@#X`30]$]$B%[7033(GV2(GOZ-C;__^%P`^$
MIP```$R)]^C(VO__B<)(F$&`?`;_+W47#Q]``(/J`4ACPD&`?`;_+T'&!`8`
M=.U$`>J!^O\/```/CT+___](@^P(N9]80`!!N8!70`!338GPN@`0``"^`0``
M`#'`2(U\)"#H;=W__XL]UW$@`.C"V___2(UT)"!(C9#X`0``OP$```#H[-G_
M_X7`6EEU'8L]L'$@`.B;V___BX`0`@``)0#P```]`(```'0=,?^^?E=``.B-
MW/__2(7`28G&#X4A____Z;C^__](C7PD$+X!````Z%W<__^%P'702(UT)!"_
M<5=``.@Z^/__2(U\)!#HD-K__^F9_O__Z.;9__]F#Q]$```/M@](B?B$R708
M2(U7`6:0@/DO#[8*2`]$PDB#P@&$R77N\\-F9F8N#Q^$``````!54TB)^TB#
M[`A(A?]T4@^V+T"$[71*Z(79__](C50#_T@YTW(4ZR=F#Q^$``````!(@^H!
M2#G:=!6`.B]T\NL%@#HO=$!(@^H!2#G3<O)(.=-U,D"`_2]U<`\?@`````"_
M`@```.BFVO__2(7`=%&Z+@```&:)$$B#Q`A;7<-FD(`Z+W4)2(/J`4@YTW+R
M2"G:2(U"`D@]`!```'<C2(G>2(/"`;D`$```O\"R8`#HO=K__TB#Q`BXP+)@
M`%M=PY!(@\0(,<!;7<-(@\0(OX!70`!;7>EWV?__#Q^``````$B#[$B_@E=`
M`&1(BP0E*````$B)1"0X,<!(BP7(%@``2(E$)!!(BP7$%@``2(E$)!A(BP7`
M%@``2(E$)"!(BP6\%@``2(E$)"@/MP6X%@``9HE$)#`QP.A4]O__,<"_BU=`
M`.A(]O__,<"_DU=``.@\]O__,<"_G%=``.@P]O__,<"_HU=``.@D]O__,<"_
MLU=``.@8]O__,<"_:%=``.@,]O__,<"_OU=``.@`]O__,<"_R5=``.CT]?__
M,<"_TU=``.CH]?__,<"_<5=``.C<]?__,<"_W5=``.C0]?__,<"_YE=``.C$
M]?__2(UT)`PQP+_Q5T``Z//T__](A<!T#TB)QK_)5T``,<#H__7__TB-="0,
M,<"_`EA``.C.]/__2(7`=`](B<:_%%A``#'`Z-KU__](C70D##'`OQ]80`#H
MJ?3__TB%P'0\2(G&OVA70``QP.BU]?__,<"^2UA``+^C5T``Z*3U__](BT0D
M.&1(,P0E*````'5:2(/$2,,/'X``````2(UT)`PQP+\O6$``Z%?T__](A<!T
M$DB)QK^_5T``,<#H8_7__^NLD$B-="0AOT!80`"Y"@```/.F=9A(C70D*[^_
M5T``,<#H//7__^N%Z/76__\/'T0``(L%,FX@`(/X_W0%PP\?0`!(@^P8,<"_
MOU=``$B-="0,Z.OS__](A<!T)@^V$(32#Y7`@/HP#Y7"#[;2(=")!?5M(`!(
M@\08PP\?A```````,<#KZ69F9BX/'X0``````$B#[`CHE];__XG'Z$#6__](
MA<!T"TB+`$B#Q`C##Q\`,<#K]&9F9BX/'X0``````$%7059)B?Y!54%40;U7
M6$``55.]35A``$B#[%A(QT0D$%=80`!(QT0D&$U80`!,C60D($C'1"0@6EA`
M`$C'1"0H4%A``$C'1"0P55A``$C'1"0X9UA``$C'1"1``````.LF9@\?1```
M2(G'Z-#8__](A<!T4TB%[70\28L$)$F)[4F#Q`A(B<5(C70D##'`3(GOZ.GR
M__](A<!(B<-,B?9T!8`X`'7!,<!,B>_H[_/__TB%[77$2(/$6%M=05Q!74%>
M05_##Q\`3(GWZ(#5__](B=])B<?H==7__TF-?`<"Z-O6__](@^P(2,?"____
M_TB)QU-)B<=!N7Y70`!-B?"YGUA``+X!````,<#H/]C__TR)_DR)[S'`Z(+S
M__]86NE0____9F8N#Q^$``````!!5T%6055!5$F)_%53OVA70`!(@>QX@0``
M9$B+!"4H````2(F$)&B!```QP$B-="0<2,=$)"!^6$``2,=$)"AF5T``2,=$
M)#``````2,=$)&`46$``2,=$)&@-6$``2,=$)'"#6$``2,=$)'@J6$``2,>$
M)(````"+6$``2,>$)(@`````````2,=$)$!R6$``2,=$)$B/6$``2,=$)%``
M````Z*CQ__](A<!T"8`X``^%2@0``#'`Z./]__](A<!(B<,/A%0$``!(B=_H
M3]3__TB-?``!Z+75__^`.P!)B<5(B<5T-F8N#Q^$``````!$#[8#2(GO,<"Y
MF%A``$C'PO____^^`0```$B#PP%(@\4"Z`G7__^`.P!UU$B-;"1HOQ180`#K
M%0\?A```````2(/%"$B+??A(A?]T.TB-="0<,<#H!_'__TB%P$B)PW3?@#@`
M=-I(B<?H<O7__X7`=,Y(B=_H9M3__TB%P$B)PW5?9@\?1```2(M<)"!(A=L/
MA%H!``"`.P"]`0```'4EZ4L!```/'P!(8\5(BUS$($B%VP^$-P$``(/%`8`[
M``^$*P$``$B)W^@3]?__A<!TUTB)W^@'U/__2(7`2(G#=,=(B=_H1]/__TR)
MZ8LQ2(/!!(V6__[^_O?6(?*!XH"`@(!TZ(G6P>X0]\*`@```#T362(UQ`D@/
M1,X`TDB#V0-,*>E$C;0(!`0``$UC]DR)]^AJU/__055HIEA``$&Y@%=``$B)
MQTB)Q4F)V+F=6$``2,?"_____[X!````,<#HS-7__[[``0``2(GOZ`_2__^#
M^/]!64%:#X2"````BST<:B``Z`?4__](C9#X`0``2(GNOP$```#H0]7__X7`
M#X23````28L,)$B+/3!J(`!)B>BZ:%E``+X!````,<#H3-7__S'`2(N4)&B!
M``!D2#,4)2@````/A9X)``!(@<1X@0``6UU!7$%=05Y!7\.0,=OIZO[__V8/
M'X0``````.A+T?__1(L(08/Y$0^$;/___TF+#"1(BSW#:2``28GHNBA90`"^
M`0```#'`Z-_4__\QP.N1#Q\`BSUB:2``Z$W3__^+@!`"```E`/```#T`0```
M#X5,____BSU!:2``Z"S3__^+F!0"``#HX='__SG##X4N____BSTC:2``Z`[3
M__^+@!`"```E_P$``#W``0``#X4-____3(GWZ`#3__](C70D'+]06$``2(G#
M,<#HK.[__TB%P$B)QP^$I@@``.@;TO__28L\)$B)QNB_]?__2(7`28G%#X2)
M"```3(GOZ$O1__^#^`-^-DACT+^K6$``N04```!)C705_/.F=2"#^`0/A'X&
M``"#Z`1(F$&`?`7_+P^$;08``&8/'T0``#'`Z"GZ__^%P'45,?9,B>_H"]/_
M_X7`B00D#X5(`0``ODM80`"_OU=``#'`Z"_O___H6M#__VCI6$``4$C'PO__
M__]!N8!70`!)B>BYQ%A``+X!````2(G?,<#HL-/__T4QY%A:ZU!F#Q^$````
M``#HN\___X,X$75/Z!'0__]!@\0!2(/L"$&Y@%=``&CI6$``051)B>A0N=)8
M0`!(Q\+_____O@$```!(B=\QP.A=T___2(/$(+[``0``2(G?Z)S/__^#^/]T
MITB)[^A/S___2(G>OVA70``QP.B`[O__2(G?Z-CY__](B=CIMOW__TB)QTB)
M!"3HQ/G__TB+!"1(B<?HN-#__^F9_?__OW)80`"]`0```.L7#Q^``````$AC
MQ8/%`4B+?,1`2(7_="M(C70D'#'`Z`3M__](A<!TWX`X`'3:2(G'Z'+0__](
MA<!(B<-TRNE>^___0+<-NW=80`#I7OO__[H"````2,?&[O___XG'08G&Z&+2
M__](C;0D8`$``+H&````1(GWZ%W0__^`O"1@`0```'4.@+PD80$``$,/A.8%
M``"+/"0QTC'VZ"G2__^XB:O-[TC'A"3@`````2-%9TC'A"3X````=E0R$$B)
MA"3H````N/[<NIA(QX0D"`$```````!(B80D\````+CPX=+#2,>$)!`!````
M````2(F$)``!``!(C80D&`$``,>$)%@!````````2(E$)`AF+@\?A```````
MBSPD2(VT)&`!``"Z`(```.BKS___A<!)B<=!B<0/CHH!``!(B[0D"`$``$EC
MUXT$UD@YQDB+M"00`0``=@1(@\8!2(F$)`@!``!(8X0D6`$``$C!ZAU(`?)(
MB90D$`$``(7`#X0W`0``0;Q`````2(V\!!@!``!(C;0D8`$``$$IQ$4YYT4/
M3N=-8^Q,B>KHC,___XN$)%@!``!$`>"#^$")A"18`0``#X52____1(GX2(V\
M).````!$*>!!B<1(C80D8`$``$D!Q>CQT___D$&#_#\/CIT```!%B>9-B>])
MBP](C;PDX````$&#[D!)@\=`2(F,)!@!``!)BT_(2(F,)"`!``!)BT_02(F,
M)"@!``!)BT_82(F,)#`!``!)BT_@2(F,)#@!``!)BT_H2(F,)$`!``!)BT_P
M2(F,)$@!``!)BT_X2(F,)%`!``#H;-/__T&#_C]_AD&#[$!$B>+!Z@:)T,'B
M!DB#P`%!*=1(P>`&20'%2(M\)`A)8]2Y2````$R)[NATSO__1(FD)%@!``#I
M9_[__P\?@`````!,C:PD8`$``.DC____BSPDZ*O-__],BZ0D"`$``$R+K"00
M`0``3(G@2,'H`X/@/XU(`4ACT,:$%!@!``"`@_DX#X^+`@``NC<```!(8\DI
MPDB-C`P0`0``2&/"2(/X"$B-40@/@\@"``"H!`^%SP,``$B%P'0,J`+&00@`
M#X7]`P``3(GH2(V\).````!$B*PD4P$``$C!Z!A$B*0D5P$``$R-O"2P````
MB(0D4`$``$R)Z$C!Z!!-C7<HB(0D40$``$R)Z$R-K"21````2,'H"(B$)%(!
M``!,B>!(P>@8B(0D5`$``$R)X$C!Z!"(A"15`0``3(G@38G\2,'H"(B$)%8!
M``#H%M+__TB+A"3@````2(G"B(0DDP```$C!ZAA$#[;"B)0DD````$B)PDC!
MZA"(E"21````2(G"2(N$).@```!(P>H(B)0DD@```$B)PHB$))<```!(P>H8
MB)0DE````$B)PDC!ZA"(E"25````2(G"2(N$)/````!(P>H(B)0DE@```$B)
MPHB$))L```!(P>H8B)0DF````$B)PDC!ZA"(E"29````2(G"2(N$)/@```!(
MP>H(B)0DF@```$B)PHB$))\```!(P>H8B)0DG````$B)PDC!ZA"(E"2=````
M2(G"2(N$)``!``!(P>H(B)0DG@```$B)PHB$)*,```!(P>H8B)0DH````$B)
MPDC!ZA"(E"2A````2(G"2,'J"(B4)*(```#I"0```$4/MD4`28/%`4R)YS'`
MN9A80`!(Q\+_____O@$```!)@\0"Z.C-__]-.?1UT\:$)-@`````:.E80`!!
M5[FU6$``O@$```!!N8!70`!)B>A(Q\+_____2(G?,<#HL,W__UE>Z6+Z__]-
MBV0D"$V%Y`^$B_G__TR)Y^B3RO__2(/X`P^&>?G__TF-=`3\O[!80`"Y!0``
M`/.F30]$[.E?^?__NC\```!(8\DIPDB-C`P0`0``B="#^`A(C5$(#X.(````
MJ`0/A5H!``"%P'0,J`+&00@`#X5>`0``2(V\).````#H"=#__TB-E"08`0``
MN0<````QP$B)U_-(J^E1_?__2,=!"`````!(@\$02,=$$/@`````2(/A^$@I
MRD@!T$B#X/A(@_@(#X(D_?__2(/@^#'22,<$$0````!(@\((2#G"<N_I"/W_
M_TC'00@`````2(/!$(G&2(/A^$C'1#+X`````$@IR@'0@^#X@_@(#X)D____
M@^#X,=*)UH/""#G"2,<$,0````!R[^E)____@+PD8@$``$$/A0SZ__^`O"1C
M`0``0P^%_OG__X"\)&0!``!(#X7P^?__@+PD90$``$4/A>+Y__]$BS0DN@(`
M``!(Q\;&____1(GWZ/_+__](C;0D8`$``+HI````1(GWZ/K)__]HZ5A``$B-
MA"1H`0``4.DS_O__#Q^``````,=!"`````#'1!#\`````.DN_/__QT$(````
M`,=$`OP`````Z:+^__]%,<!F1(E$`O[IE/[__TV++"3I;O?__S'_9HE\$/[I
M]_O__^C`R/__055!5%532(/L&(L]$&`@`.C[R?__2(UT)`S&@+$````!OZ-7
M0``QP.BSY?__2(7`=`F`.#$/A$4"```QP.BN[___BSW87R``Z,/)__^Y"P``
M`+H!````ON-80`!(B<?H7,G__TB%P`^$M````(,]/'`@``%(BT`03(M@*`^.
MGP```#'MNP$```#K,`\?1```28MU$$B+!0UP(`!(8]-(BSS0Z`G)__^%P'5E
MBP7_;R``@\,!@\4!.=A^6XL]7U\@`.A*R?__,<E(8]5,B>9(B<?H&LK__TB%
MP'0U3(LH08M%#"4`!"``/0`$``!THHL]+%\@`.@7R?__3(GNN0(````QTDB)
MQ^@%R/__2(G&ZX2+!9IO(`"-4/\YZ@^$'P$``(L]^5X@`.CDR/__N0,```"Z
M`0```+[H6$``2(G'Z'W(__](A<!(B<-T,TB+0!"+/<M>(`!(BRCHL\C__[KJ
M6$``2(G'2(GNZ)/'__](BT,02(L8]D,.0`^%#0(``(L]G%X@`.B'R/__N0,`
M``"Z`0```+[O5T``2(G'Z"#(__](A<!(B<5T/4B-="0,,<"_<5=``.@GY/__
M2(7`2(G##X13`0``2(M%$(L]45X@`$R+(.@YR/__2(G:2(G'3(GFZ!O'__^+
M/35>(`#H(,C__TB-="0,QH"Q`````+]H5T``,<#HV./__TB%P$B)PTB)!:-N
M(`!T>;[``0``2(G'Z-S%__^-4`&#^@%V"8/X$0^%>P$``$B#Q!A;74%<05W#
M@_@!#X[8_O__NP$```!FD(L]RET@`(/#`>BRQ___3(GF2(G'Z+?%__\Y'4%N
M(`!_W^FK_O__9BX/'X0``````(!X`0`/A+C]___IK/W__Y!(BST1;B``Z/3P
M__](A<!(B042;B``#X3Z````2(M%$$R+)?%M(`!(BQB+0PPE``0@`#T`!```
M#X69````2(M[$$R)YNAGR/__08G$2(M%$$B+&(M3#('B``0@`('Z``0``'50
M2(M3$$B+!:EM(`!$B>&_Z%E``$B+,#'`Z!_'__\/'X``````2(L%B6T@`(L]
M^UP@`$R+($B+11!(BQCHW,;__TR)YDB)W^BQY___Z:'^__^+/=9<(`#HP<;_
M_S'2N0(```!(B=Y(B<?HK\7__TB)PNN2BSVT7"``Z)_&__^Y`@```$B)QS'2
M2(G>Z(W%__](B<?I1O___XL]CUP@`.AZQO__2(G>2(G'Z,_&___IV/W__[_`
M64``Z(#&__^)P4B+!>]L(`!(B=J_$%I``$B+,#'`Z&7&__\/'T0``%532(G]
M2(/L".@RZ___#[8(2(G#A,ET&DB-4`$/'T``@/DO#[8*2`]$VDB#P@&$R77N
M,<#HQ^W__X7`=!U(A>UT&(!]``!T$KZF6$``2(G?Z'O'__](.=AT!TB#Q`A;
M7<-(@\0(2(GO6UWI\>3__Y!(C06Y6R``2(7`=!1(BPVM6R``Z?C$__\/'X0`
M`````#')Z>G$__]F#Q^$``````!!5T%608G_055!5$R-)?Y6(`!52(TM_E8@
M`%-)B?9)B=4QVTPIY4B#[`A(P?T#Z.W"__](A>UT'@\?A```````3(GJ3(GV
M1(G_0?\4W$B#PP%(.>MUZDB#Q`A;74%<05U!7D%?PV9F+@\?A```````\\,`
M`$B#[`A(@\0(PP````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A
M9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R
M;V,O)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"
M`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?
M4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'
M0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$
M25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@!005)?0TQ%04X]`#$`3$E"4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)
M0E]0051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`
M)3`R>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E
M<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`+64`
M+2T`````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("```'!E<FQX
M<VDN8P``````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E
M=')Y('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0``````````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL
M960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,[
M"FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D[
M"D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^
M("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S
M:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?
M=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I
M"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^
M9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM
M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F
M)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T
M;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?
M,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[
M(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P
M(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I
M('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P
M<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X
M(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T
M(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E
M:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A
M9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B
M)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED
M>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@
M/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q
M,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD
M;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E
M860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH
M(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H
M)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@
M*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S
M92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@
M*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[
M4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO
M)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO
M<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D
M92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@
M>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D
M;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN
M97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N
M86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL
M96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F
M:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP
M<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E
M;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N
M;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H
M4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U
M;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I
M<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*
M=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R
M"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H
M:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8[
M"GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?
M:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB
M<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H
M($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@
M(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?
M87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*
M96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF
M("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E
M<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@
M;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]
M("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@
M*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H
M9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R
M."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO
M="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@
M)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2([
M"GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II
M<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z
M)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>
M.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN
M960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P
M87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL
M92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H
M*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I
M;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I
M;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H
M*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N
M9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(
M/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L
M("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@
M)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I
M9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N
M('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI
M("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@
M+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*
M?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D
M8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H
M*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD
M;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL
M:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI
M.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO
M861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X[
M"F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL
M92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]
M"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE
M+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E
M<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R
M968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL
M92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]
M*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI
M8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@
M)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY
M("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE
M+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I
M92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N
M=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M
M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E
M,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I
M+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M
M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z
M.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T
M.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U
M+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I
M;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]
M("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H
M95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E
M<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC
M:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE
M9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE
M.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@
M)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O
M:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN
M97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]
M+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD
M"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&
M:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N
M86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU
M;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E
M<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M
M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA
M;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE
M3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF
M("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G
M93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@
M<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F
M:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H
M)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR
M97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G
M97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E
M('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[
M($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V
M97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`[
M"FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E
M<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@
M*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE*3L*
M)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF("@D14Y6>U!!
M4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64[
M"G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N("AU
M;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N("1F
M:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E
M='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA
M;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]
M7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F
M:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z
M.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]
M?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG
M>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!
M3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%
M3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@
M)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%
M04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI
M('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H
M*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^
M("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH```````$;`SOD````
M&P```/B!__\P`0``"(;__S`&``#0A___``$``-B(__]8`0``**#__Z@!``#H
MH/__"`(``$BA__\H`@``>*/__W@"``"HI/__N`(``#BE___8`@``"*;__Q`#
M```XIO__*`,``(BF__]``P``2*?__V@#``!8I___@`,``"BI___8`P``6*G_
M__`#```XJO__0`0``!BL__]@!```>*S__X`$``"HK/__H`0``-BM__\`!0``
M2+K__[@%```8OO__^`4``(B^__]8!@``N+[__W`&```HO___N`8````````4
M``````````%Z4@`!>!`!&PP'")`!!Q`4````'````,B&__\J````````````
M```4``````````%Z4@`!>!`!&PP'")`!```D````'````,"`__\0!`````X0
M1@X82@\+=PB``#\:.RHS)"(`````3````$0```!XA___1A<```!"#A"/`D(.
M&(X#1@X@C01"#BB,!4,.,(8&00XX@P='#L@$`R07#CA!#C!!#BA"#B!"#AA"
M#A!"#@@```````!<````E````'B>__^W`````$(.$(\"0@X8C@-%#B"-!$(.
M*(P%00XPA@9!#CB#!T0.0`)Q"@XX0PXP00XH0@X@0@X80@X00@X(0@M<#CA!
M#C!!#BA"#B!"#AA"#A!"#@@<````]````-B>__]8`````$$.$(,"1PX@`DX.
M$$$."$P````4`0``&)___R$"````0@X0CP)"#AB.`T0.((T$0@XHC`5!#C"&
M!D$..(,'2@Y@`O@*#CA!#C!!#BA"#B!"#AA"#A!"#@A("P``````/````&0!
M``#XH/__+P$```!2#A"-`D(.&(P#00X@A@1!#BB#!4H.P`$"UPH.*$'##B!!
MQ@X80LP.$$+-#@A#"QP```"D`0``Z*'__X$`````00X0@P)I"@X(1@L"4`X(
M-````,0!``!8HO__R`````!"#A",`D$.&(8#1`X@@P14#K`@`GD*#B!!#AA!
M#A!"#@A("P`````4````_`$``/"B__\J`````$0.$&$."``4````%`(```BC
M__]$`````$0.$'L."``D````+`(``$"C__^Y`````$$.$(,"1PZP0`*>"@X0
M00X(20L`````%````%0"``#8H___!0``````````````5````&P"``#0H___
MR@$```!"#A".`D(.&(T#0@X@C`1!#BB&!40.,(,&3P[0(`)B"@XP00XH00X@
M0@X80@X00@X(00L"B0[8($P.X"!]#M@@00[0(````!0```#$`@``2*7__R0`
M`````````````$P```#<`@``8*7__]D`````00X0A@)!#AB#`T<.(`)R"@X8
M00X000X(0PMW"@X81@X000X(0@M$"@X80PX000X(00M$#AA&#A!!#@@`````
M'````"P#``#PI?__VP$```!$#E`#?`$*#@A("P`````<````3`,``+"G__]4
M`````%0.(',*#@A)"P```````!P```!L`P``\*?__R0`````1`X06`H."$0+
M````````7````(P#````J/__)0$```!"#A"/`D(.&(X#10X@C01"#BB,!4<.
M,(8&00XX@P=)#I`!`IX*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"V$.F`%+#J`!
M:PZ8`4$.D`$`````M````.P#``#0J/__<`P```!"#A"/`D(.&(X#0@X@C01"
M#BB,!40.,(8&00XX@P=,#K"#`@,/`@ZX@P)%#L"#`GD.N(,"0@ZP@P(";`H.
M.$$.,$$.*$(.($(.&$(.$$(."$(+`VL!#KB#`D$.P(,":`ZX@P)!#K"#`F(.
MN(,"2P[`@P)"#LB#`D0.T(,"7PZP@P(#@P4.N(,"0@[`@P)E#KB#`D$.L(,"
M`YD!"@ZX@P))#L"#`DP+`#P```"D!```B+3__\L#````0@X0C0)"#AB,`T$.
M((8$00XH@P5$#D`#+P(*#BA!#B!!#AA"#A!"#@A!"P`````T````Y`0``!BX
M__]O`````$$.$(8"00X8@P-'#B`"50H.&$$.$$$."$$+1`X81`X000X(````
M`"0````<!0``T'___\@!````00X0@P)$#D`#<@$*#A!##@A!"P`````4````
M1`4``"BX__\G``````````````!$````7`4``$"X__]E`````$(.$(\"0@X8
MC@-%#B"-!$(.*(P%2`XPA@9(#CB#!T\.0'`..$$.,$$.*$(.($(.&$(.$$(.
M"``4````I`4``&BX__\"````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````@"!```````!@($``
M`````````````````0`````````!``````````$`````````Q`$````````!
M`````````!,"`````````0`````````?`@````````$`````````*@(`````
M```!`````````#0"`````````0````````!"`@````````$`````````3P(`
M```````,`````````+`90```````#0`````````$5T```````!D`````````
MH*U@```````;``````````@`````````&@````````"HK6```````!P`````
M````"`````````#U_O]O`````)@"0```````!0````````#X#$````````8`
M````````F`-````````*`````````/@$````````"P`````````8````````
M`!4````````````````````#``````````"P8````````@``````````!@``
M`````!0`````````!P`````````7`````````+`30```````!P`````````X
M$T````````@`````````>``````````)`````````!@`````````_O__;P``
M``"X$D```````/___V\``````@````````#P__]O`````/`10```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"XK6````````````````````````````#F&4```````/89
M0```````!AI````````6&D```````"8:0```````-AI```````!&&D``````
M`%8:0```````9AI```````!V&D```````(8:0```````EAI```````"F&D``
M`````+8:0```````QAI```````#6&D```````.8:0```````]AI````````&
M&T```````!8;0```````)AM````````V&T```````$8;0```````5AM`````
M``!F&T```````'8;0```````AAM```````"6&T```````*8;0```````MAM`
M``````#&&T```````-8;0```````YAM```````#V&T````````8<0```````
M%AQ````````F'$```````#8<0```````1AQ```````!6'$```````&8<0```
M````=AQ```````"&'$```````)8<0```````IAQ```````"V'$```````,8<
M0```````UAQ```````#F'$```````/8<0```````!AU````````6'4``````
M`"8=0```````-AU```````!&'4```````%8=0```````9AU```````!V'4``
M`````(8=0```````EAU```````"F'4```````+8=0```````QAU```````#6
M'4````````````````````````````#_____`````%A:0```````1T-#.B`H
M1TY5*2`T+CDN,@``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N
M;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`
M+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"`````````#@"0```````.`(`````
M```<`````````````````````0```````````````````!,````'`````@``
M``````!4`D```````%0"````````(`````````````````````0`````````
M```````````A````!P````(`````````=`)```````!T`@```````"0`````
M```````````````$````````````````````-````/;__V\"`````````)@"
M0```````F`(``````````0````````4`````````"```````````````````
M`#X````+`````@````````"8`T```````)@#````````8`D````````&````
M`0````@`````````&`````````!&`````P````(`````````^`Q```````#X
M#````````/@$```````````````````!````````````````````3@```/__
M_V\"`````````/`10```````\!$```````#(``````````4``````````@``
M```````"`````````%L```#^__]O`@````````"X$D```````+@2````````
M@``````````&`````@````@```````````````````!J````!`````(`````
M````.!-````````X$P```````'@`````````!0`````````(`````````!@`
M````````=`````0````"`````````+`30```````L!,`````````!@``````
M``4````,````"``````````8`````````'X````!````!@````````"P&4``
M`````+`9````````&@````````````````````0```````````````````!Y
M`````0````8`````````T!E```````#0&0```````!`$````````````````
M```0`````````!``````````A`````$````&`````````.`=0```````X!T`
M```````B.0``````````````````$````````````````````(H````!````
M!@`````````$5T````````17````````"0````````````````````0`````
M``````````````"0`````0````(`````````$%=````````05P```````,A`
M```````````````````(````````````````````F`````$````"````````
M`-B70```````V)<```````#D````````````````````!```````````````
M`````*8````!`````@````````#`F$```````,"8````````[`4`````````
M``````````@```````````````````"P````#@````,`````````H*U@````
M``"@K0````````@````````````````````(````````````````````O```
M``\````#`````````*BM8```````J*T````````(````````````````````
M"````````````````````,@````!`````P````````"PK6```````+"M````
M````"`````````````````````@```````````````````#-````!@````,`
M````````N*U@``````"XK0```````$`"````````!@`````````(````````
M`!``````````U@````$````#`````````/BO8```````^*\````````(````
M````````````````"``````````(`````````-L````!`````P``````````
ML&````````"P````````&`(```````````````````@`````````"```````
M``#D`````0````,`````````&+)@```````8L@```````"``````````````
M```````(````````````````````Z@````@````#`````````$"R8```````
M.+(```````"H$```````````````````0````````````````````.\````!
M````,````````````````````#BR````````$0````````````````````$`
M`````````0`````````!`````P````````````````````````!)L@``````
A`/@````````````````````!````````````````````
